@@ -30,6 +30,7 @@
 #include "twitterapplicationitem.h"
 #include "applicationItems/twitterbutton.h"
 #include "applicationItems/lineedit.h"
+#include "account.h"
 
 #ifdef Q_WS_MAEMO_5
     #include <QMaemo5InformationBox>
@@ -59,6 +60,7 @@ private slots:
     void _enableButton(void);
     void _authorize(void);
     void _saveTokens(void);
+    void _changeOrientation(void);
 
 protected:
     void mousePressEvent(QGraphicsSceneMouseEvent *event);
@@ -74,6 +76,7 @@ private:
     QGraphicsRectItem *_bg;
     QGraphicsLineItem *_sep1;
     QGraphicsLineItem *_sep2;
+    QGraphicsLineItem *_sep3;
     QGraphicsTextItem *_title;
     QGraphicsTextItem *_text1;
     QGraphicsTextItem *_text2;
@@ -82,6 +85,9 @@ private:
     TwitterButton *_allowButton;
     TwitterButton *_validateButton;
     LineEdit *_pinEntry;
+    QPointF _startPos;
+    QPointF _endPos;
+    bool _anim;
     QFont font;
     int _step;
 
