@@ -26,7 +26,6 @@
 #include <QtGui/QApplication>
 
 #include "loginview.h"
-#include "applicationItems/dialog.h"
 #include "applicationItems/user.h"
 #include "applicationItems/oauthwizard.h"
 
@@ -48,7 +47,6 @@ public:
 private:
     QGraphicsScene *_scene;
     LoginView *_loginView;
-    DialogView *_dialog;
     bool _autologin;
 
 private:
@@ -56,7 +54,6 @@ private:
 
 private slots:
     void _loginTwitter(void);
-    void _exitButtonPressed(void);
     void _connectionError(QString);
     void _exit(void);
     void _abort(void);
@@ -64,6 +61,7 @@ private slots:
 
 signals:
     void accountConnected(void);
+    void lockRotation(bool);
     void done(void);
 };
 
