@@ -65,6 +65,8 @@ signals:
 
 protected:
     QDateTime toDateTime( const QString &timestamp );
+    QString parseCreatedAt(QDateTime timestamp);
+    QString parseSource(QString source);
     int getMonth( const QString &month );
     void parseUserInfo(const QString &ch);
     static inline int getTimeShift();
@@ -77,6 +79,7 @@ protected:
     EntryList data;
     bool important;
     bool parsingUser;
+    bool parsingRetweet;
     bool favoritedSet;
     int level;
 
@@ -107,6 +110,9 @@ protected:
     static const QString TAG_STATUS_COUNT;
     static const QString TAG_SOURCE;
     static const QString TAG_RETWEET_COUNT;
+    static const QString TAG_FAVOURITES_COUNT;
+    static const QString TAG_VERIFIED;
+    static const QString TAG_RETWEETED_STATUS;
     //  static const QString TAG_NOTIFICATIONS;
     //  static const QString TAG_FOLLOWING;
 
